CREATE TABLE ta_housing_resources(
    `house_id` INT NOT NULL AUTO_INCREMENT  COMMENT '房源id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `building_name` VARCHAR(128)    COMMENT '楼盘名称' ,
    `term_id` INT    COMMENT '期id' ,
    `term_name` VARCHAR(32)    COMMENT '期名称' ,
    `block_id` INT    COMMENT '楼栋 与楼盘区分' ,
    `block_name` VARCHAR(32)    COMMENT '楼栋名称' ,
    `sales_batch_id` VARCHAR(32)    COMMENT '销售批次id' ,
    `unit_id` INT    COMMENT '单元id' ,
    `unit_name` VARCHAR(32)    COMMENT '单元名称' ,
    `floor_id` INT    COMMENT '层id' ,
    `floor_name` VARCHAR(32)    COMMENT '楼层名称' ,
    `room_id` INT    COMMENT '房号id' ,
    `room_name` VARCHAR(32)    COMMENT '房间名称' ,
    `price` DECIMAL(32,8)    COMMENT '价格' ,
    `heat` INT    COMMENT '基础热度' ,
    `real_heat` INT    COMMENT '实际热度' ,
    `apartment_id` VARCHAR(32)    COMMENT '户型id' ,
    `status` INT    COMMENT '状态' ,
    `org_id` INT    COMMENT '公司id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `update_date` DATETIME    COMMENT '更新时间' ,
    `update_user` INT    COMMENT '更新人id' ,
    PRIMARY KEY (house_id)
) COMMENT = '房源表 ';;

CREATE TABLE ta_preselection_record(
    `preselection_record_id` INT NOT NULL AUTO_INCREMENT  COMMENT '预选记录id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `org_id` INT    COMMENT '公司id' ,
    `sales_batch_id` INT    COMMENT '销售批次id' ,
    `building_id` VARCHAR(32)    COMMENT '楼盘ID' ,
    `update_date` VARCHAR(32)    COMMENT '更新时间' ,
    `house_id` VARCHAR(32)    COMMENT '房源id' ,
    `person_id` VARCHAR(3072)    COMMENT '小程序用户id' ,
    `status` INT    COMMENT '状态' ,
    `update_user` INT    COMMENT '更新人' ,
    PRIMARY KEY (preselection_record_id)
) COMMENT = '预选记录表 ';;

CREATE TABLE ta_sales_batch(
    `sales_batch_id` INT NOT NULL AUTO_INCREMENT  COMMENT '销售批次id' ,
    `org_id` INT    COMMENT '公司id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `sales_batch_name` VARCHAR(128)    COMMENT '销售批次名称' ,
    `sales_number` INT    COMMENT '出售房源数' ,
    `preselection_start_time` DATETIME    COMMENT '预选开始时间' ,
    `preselection_end_time` DATETIME    COMMENT '预选结束时间' ,
    `status` INT    COMMENT '发布状态' ,
    `update_time` DATETIME    COMMENT '修改时间' ,
    `aerial_view_img` VARCHAR(3072)    COMMENT '分栋鸟瞰图' ,
    `remark` VARCHAR(3072)    COMMENT '备注 涉及楼栋' ,
    `qr_code` VARCHAR(3072)    COMMENT '小程序二维码' ,
    PRIMARY KEY (sales_batch_id)
) COMMENT = '销售批次表 ';;

CREATE TABLE ta_building_block(
    `block_id` INT NOT NULL AUTO_INCREMENT  COMMENT '楼栋id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `term_id` INT    COMMENT '期id' ,
    `block_name` VARCHAR(32)    COMMENT '楼栋名称' ,
    `status` INT    COMMENT '状态' ,
    `org_id` INT    COMMENT '公司id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `update_date` DATETIME    COMMENT '更新时间' ,
    PRIMARY KEY (block_id)
) COMMENT = '楼栋表 ';;

CREATE TABLE ta_building_unit(
    `unit_id` INT NOT NULL AUTO_INCREMENT  COMMENT '房源id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `term_id` INT    COMMENT '期id' ,
    `block_id` INT    COMMENT '楼栋id 与楼盘区分' ,
    `unit_name` VARCHAR(32)    COMMENT '单元' ,
    `status` INT    COMMENT '状态' ,
    `org_id` INT    COMMENT '公司id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `update_date` DATETIME    COMMENT '更新时间' ,
    PRIMARY KEY (unit_id)
) COMMENT = '单元表 ';;

CREATE TABLE ta_building_floor(
    `floor_id` INT NOT NULL AUTO_INCREMENT  COMMENT '房源id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `term_id` INT    COMMENT '期id' ,
    `block_id` INT    COMMENT '楼栋id 与楼盘区分' ,
    `unit_id` INT    COMMENT '单元id' ,
    `floor_name` VARCHAR(32)    COMMENT '层' ,
    `status` INT    COMMENT '状态' ,
    `org_id` INT    COMMENT '公司id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `update_date` DATETIME    COMMENT '更新时间' ,
    PRIMARY KEY (floor_id)
) COMMENT = '楼层表 ';;

CREATE TABLE ta_building_room(
    `room_id` INT NOT NULL AUTO_INCREMENT  COMMENT '房间id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `term_id` INT    COMMENT '期id' ,
    `block_id` INT    COMMENT '楼栋 与楼盘区分' ,
    `unit_id` INT    COMMENT '单元id' ,
    `floor_id` INT    COMMENT '层id' ,
    `room_name` VARCHAR(32)    COMMENT '房间名称' ,
    `status` INT    COMMENT '状态' ,
    `org_id` INT    COMMENT '公司id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `update_date` DATETIME    COMMENT '更新时间' ,
    PRIMARY KEY (room_id)
) COMMENT = '房间表 ';;

CREATE TABLE ta_building_term(
    `term_id` INT NOT NULL AUTO_INCREMENT  COMMENT '楼栋期id' ,
    `building_id` VARCHAR(64)    COMMENT '楼盘id' ,
    `term_name` VARCHAR(32)    COMMENT '楼栋名称' ,
    `status` INT    COMMENT '状态' ,
    `org_id` INT    COMMENT '公司id' ,
    `create_date` DATETIME    COMMENT '创建时间' ,
    `update_date` DATETIME    COMMENT '更新时间' ,
    PRIMARY KEY (term_id)
) COMMENT = '楼栋期表 ';;



insert into td_person_from(from_id, from_code, from_name, status) values(11,'house_share', '房源分享', 1);

update td_points_rules t set t.remark = '海报分享转发后客户扫码进入可获得积分' where t.rule_name = '分享转发'